C++ API reference
=================

This is the complete reference for the (internal) C++ API of :code:`py4dgeo`.
You only need to consult this documentation if you are aiming to extend the
C++ core of :code:`py4dgeo`.

.. doxygenclass:: py4dgeo::KDTree
   :members:

.. doxygenfunction:: py4dgeo::compute_distances

.. doxygenfunction:: py4dgeo::compute_multiscale_directions
